@@ -203,12 +203,16 @@ use std::io::Write;
 use std::mem;
 use std::sync::Arc;
 
-use ratatui::prelude::*;
-use ratatui::widgets::*;
-
 use chrono::{DateTime, Local};
 use log::{Level, LevelFilter, Log, Metadata, Record};
 use parking_lot::Mutex;
+use ratatui::{
+    buffer::Buffer,
+    layout::{Constraint, Direction, Layout, Rect},
+    style::{Modifier, Style},
+    text::Line,
+    widgets::{Block, BorderType, Borders, Widget},
+};
 
 mod circular;
 #[cfg(feature = "slog-support")]
@@ -835,25 +839,26 @@ impl<'b> Widget for TuiLoggerTargetWidget<'b> {
                     (3, "D", Level::Debug),
                     (4, "T", Level::Trace),
                 ] {
-                    let cell = buf.get_mut(la_left + j, la_top + i as u16);
-                    let cell_style = if *hot_level_filter >= *lev {
-                        if *level_filter >= *lev {
-                            if !focus_selected || i + offset == state.selected {
-                                self.style_show
+                    if let Some(cell) = buf.cell_mut((la_left + j, la_top + i as u16)) {
+                        let cell_style = if *hot_level_filter >= *lev {
+                            if *level_filter >= *lev {
+                                if !focus_selected || i + offset == state.selected {
+                                    self.style_show
+                                } else {
+                                    self.style_hide
+                                }
                             } else {
                                 self.style_hide
                             }
+                        } else if let Some(style_off) = self.style_off {
+                            style_off
                         } else {
-                            self.style_hide
-                        }
-                    } else if let Some(style_off) = self.style_off {
-                        style_off
-                    } else {
-                        cell.set_symbol(" ");
-                        continue;
-                    };
-                    cell.set_style(cell_style);
-                    cell.set_symbol(sym);
+                            cell.set_symbol(" ");
+                            continue;
+                        };
+                        cell.set_style(cell_style);
+                        cell.set_symbol(sym);
+                    }
                 }
                 buf.set_stringn(la_left + 5, la_top + i as u16, ":", la_width, self.style);
                 buf.set_stringn(
